faker\_file.providers package
=============================

Subpackages
-----------

.. toctree::
   :maxdepth: 20

   faker_file.providers.augment_file_from_dir
   faker_file.providers.helpers
   faker_file.providers.mixins
   faker_file.providers.mp3_file

Submodules
----------

faker\_file.providers.bin\_file module
--------------------------------------

.. automodule:: faker_file.providers.bin_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.csv\_file module
--------------------------------------

.. automodule:: faker_file.providers.csv_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.docx\_file module
---------------------------------------

.. automodule:: faker_file.providers.docx_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.eml\_file module
--------------------------------------

.. automodule:: faker_file.providers.eml_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.epub\_file module
---------------------------------------

.. automodule:: faker_file.providers.epub_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.ico\_file module
--------------------------------------

.. automodule:: faker_file.providers.ico_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.jpeg\_file module
---------------------------------------

.. automodule:: faker_file.providers.jpeg_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.odp\_file module
--------------------------------------

.. automodule:: faker_file.providers.odp_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.ods\_file module
--------------------------------------

.. automodule:: faker_file.providers.ods_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.odt\_file module
--------------------------------------

.. automodule:: faker_file.providers.odt_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.pdf\_file module
--------------------------------------

.. automodule:: faker_file.providers.pdf_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.png\_file module
--------------------------------------

.. automodule:: faker_file.providers.png_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.pptx\_file module
---------------------------------------

.. automodule:: faker_file.providers.pptx_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.random\_file\_from\_dir module
----------------------------------------------------

.. automodule:: faker_file.providers.random_file_from_dir
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.rtf\_file module
--------------------------------------

.. automodule:: faker_file.providers.rtf_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.svg\_file module
--------------------------------------

.. automodule:: faker_file.providers.svg_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.tar\_file module
--------------------------------------

.. automodule:: faker_file.providers.tar_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.txt\_file module
--------------------------------------

.. automodule:: faker_file.providers.txt_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.webp\_file module
---------------------------------------

.. automodule:: faker_file.providers.webp_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.xlsx\_file module
---------------------------------------

.. automodule:: faker_file.providers.xlsx_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.zip\_file module
--------------------------------------

.. automodule:: faker_file.providers.zip_file
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: faker_file.providers
   :members:
   :undoc-members:
   :show-inheritance:
